import { Component, OnInit } from '@angular/core';
import {ResourceService} from "../../service/resource.service";
import {ActivatedRoute, Router} from "@angular/router";
import {environment} from "../../../environments/environment";
import {Resource} from "../../model/resource";
import {ConfirmationService, MessageService} from "primeng/api";
import {Observable} from "rxjs";
import {User} from "../../model/user";
import {UserState} from "../../states/user.state";
import {Store} from "@ngxs/store";

@Component({
  selector: 'app-resource',
  templateUrl: './resource.component.html',
  styleUrls: ['./resource.component.css']
})
export class ResourceComponent implements OnInit {
  resource: Resource ={};
  imagePath = environment.baseUrl+"/resource/image";
  filePath = environment.baseUrl+"/resource/file";
  url:any;
  resourceId = null;
  // @ts-ignore
  public loggeduser: Observable<User> = this.store.select(UserState.userDetails);

  constructor(private resourceService:ResourceService, private route: ActivatedRoute,
              private router: Router, private store:Store, private messageService:MessageService, private confirmationService: ConfirmationService) { }

  ngOnInit(): void {
    // @ts-ignore
    this.resourceId = this.route.snapshot.paramMap.get('id');
    // @ts-ignore
     this.resourceService.getResource(this.resourceId).subscribe(data =>{
       this.resource =data;
     });

  }
  downloadFile(fileName: any): void {
    console.log("file")
    this.resourceService.downloadFile(fileName).subscribe((file: any) => {
      const blob = new Blob([file], {type: 'application/pdf'});

      this.url = window.URL.createObjectURL(file);
      const link = document.createElement('a');
      link.href = this.url;
      link.download = fileName;
      link.click();
    }, error => {
      console.log(error)
    });
  }

  approve(event: Event) {
    this.confirmationService.confirm({
      message: 'Are you sure that you want to approve resource?',
      icon: 'pi pi-exclamation-triangle',
      accept: () => {
        // @ts-ignore
        this.resourceService.approveResource(this.resourceId).subscribe(r =>{
          this.messageService.add({severity:'success', detail:'Resource has been approved.'});
          this.router.navigate(['/home'])
        },error =>{
          this.messageService.add({severity:'error', detail:'Some error occured!'});
        }
      );
      }
      });
  }
  showInfo() {
    this.messageService.add({severity:'info', summary: 'Info', detail: 'This feature has not been implemented yet!'});
  }
}
